#!/usr/bin/python

import dbacsv
import unittest

class TestCSV(unittest.TestCase):
	def testNothing(self):
		pass

unittest.main()
